Learn R Programming

mmod (version 1.2.1)

jacknife_populations: Create jacknife samples of a genind object by population

Description

Makes a series of jacknife samples across populations from a genind object. This function returns a list of genind objects that can then be further processed (see examples below).

Usage

jacknife_populations(x, sample_frac = 0.5, nreps = 1000)

Arguments

x
genind object (from package adegenet)
sample_frac
fraction of pops to sample in each replication (default 0.5)
nreps
number of jacknife replicates to run (default 1000)

Value

  • a list of genind objects to be further processed

See Also

Other resample: chao_bootstrap; summarise_bootstrap

Examples

Run this code
data(nancycats)
obs <- diff_stats(nancycats)
jn <- jacknife_populations(nancycats)
jn.D <- summarise_bootstrap(jn, D_Jost)

Run the code above in your browser using DataLab