Gst_Hedrick: Calculate Nei's Gst using estimators for Hs and Ht
Description
This function calculates Hedrick's G'st from a genind
object
Usage
Gst_Hedrick(x)
Arguments
x
genind object (from package adegenet)
Details
Takes a genind object with population information and
calculates Hedrick's G''st. This Returns a list with
values for each locus as well as a global estimates
Because estimators of Hs and Ht are used, it's possible
to have negative estimates of Gst. You should treat such
results as zeros (or estimating a value close to zero,
and getting it a little wrong)
References
Hedrick, PW. (2005), A Standardized Genetic
Differentiation Measure. Evolution 59: 1633-1638.
Meirmans PG, Hedrick PW (2011), Assessing population
structure: FST and related measures. Molecular Ecology
Resources, 11:5-18