summarise_bootsrap: Apply a differentiation statistic to a bootstrap sample
Description
This function applies a differentiation statistic (eg,
D_Jost, Gst_Hedrick or Gst_Nei) to a list of genind
objects, possibly produced with chao_bootsrap or
jacknife_populations. The resulting list contains a
matrix of values with the statistic for each locus as
well as a global estimate for every object in the sample.
Additionally, mean and 95 calculated for each set of statisics A custom print
method that displays these summaries is provided.